ib 2004/04/09 08:47:04
Modified: webdavclient/clientlib/src/java/org/apache/webdav/lib/methods
XMLResponseMethodBase.java
Log:
Apply workaround to accept Ok instead of Multistatus for ReportMethod
Revision Changes Path
1.5 +10 -7
jakarta-slide/webdavclient/clientlib/src/java/org/apache/webdav/lib/methods/XMLResponseMethodBase.java
Index: XMLResponseMethodBase.java
===================================================================
RCS file:
/home/cvs/jakarta-slide/webdavclient/clientlib/src/java/org/apache/webdav/lib/methods/XMLResponseMethodBase.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- XMLResponseMethodBase.java 11 Feb 2004 13:50:35 -0000 1.4
+++ XMLResponseMethodBase.java 9 Apr 2004 15:47:04 -0000 1.5
@@ -254,9 +254,10 @@
*/
public void parseResponse(InputStream input, HttpState state, HttpConnection
conn)
throws IOException, HttpException {
// Also accept OK sent by buggy servers in reply to a PROPFIND.
if (getStatusCode() == WebdavStatus.SC_MULTI_STATUS
- || this instanceof PropFindMethod
+ || (this instanceof PropFindMethod || this instanceof ReportMethod)
&& getStatusCode() == HttpStatus.SC_OK) {
try {
parseXMLResponse(input);
@@ -328,9 +329,11 @@
responseURLs = new Vector();
int status = getStatusLine().getStatusCode();
// Also accept OK sent by buggy servers in reply to a PROPFIND.
if (status == WebdavStatus.SC_MULTI_STATUS
- || this instanceof PropFindMethod
+ || (this instanceof PropFindMethod
+ || this instanceof ReportMethod)
&& status == HttpStatus.SC_OK) {
Element multistatus =
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
@@ -254,9 +254,10 @@
conn)
throws IOException, HttpException {
- // Also accept OK sent by buggy servers in reply to a PROPFIND.
+ // Also accept OK sent by buggy servers in reply to a PROPFIND or
+ // REPORT (Xythos, Catacomb, ...?).
if (getStatusCode() == WebdavStatus.SC_MULTI_STATUS
@@ -328,9 +329,11 @@
responseURLs = new Vector();
int status = getStatusLine().getStatusCode();
- // Also accept OK sent by buggy servers in reply to a PROPFIND.
+ // Also accept OK sent by buggy servers in reply to a PROPFIND
+ // or REPORT (Xythos, Catacomb, ...?).
if (status == WebdavStatus.SC_MULTI_STATUS